'use strict';

exports.__esModule = true;

var _parser = require('./parser');

var _parser2 = _interopRequireDefault(_parser);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var Processor = function () {
    function Processor(func) {
        _classCallCheck(this, Processor);

        this.func = func || function noop() {};
        this.funcRes = null;
        return this;
    }

    Processor.prototype._input = function _input(rule) {
        var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

        return new _parser2.default({
            css: rule,
            error: function error(e, opts) {
                if (typeof rule === 'string') {
                    throw new Error(e);
                }
                throw rule.error(e, opts); // eslint-disable-line new-cap
            },
            options: options
        });
    };

    Processor.prototype.process = function process(rule, options) {
        var input = void 0;
        try {
            input = this._input(rule, options);
        } catch (e) {
            return Promise.reject(e);
        }
        return Promise.resolve(this.func(input)).then(function () {
            return String(input);
        });
    };

    Processor.prototype.processSync = function processSync(rule) {
        var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

        var input = this._input(rule, options);
        this.func(input);
        return String(input);
    };

    return Processor;
}();

exports.default = Processor;
module.exports = exports['default'];